Function coincbc_sys::Cbc_loadProblem
source · pub unsafe extern "C" fn Cbc_loadProblem(
model: *mut Cbc_Model,
numcols: c_int,
numrows: c_int,
start: *const CoinBigIndex,
index: *const c_int,
value: *const f64,
collb: *const f64,
colub: *const f64,
obj: *const f64,
rowlb: *const f64,
rowub: *const f64
)Expand description
Loads a problem (the constraints on the rows are given by lower and upper bounds). If a pointer is NULL then the following values are the default:
-
colub: all columns have upper bound infinity -
collb: all columns have lower bound 0 -
rowub: all rows have upper bound infinity -
rowlb: all rows have lower bound -infinity -
obj: all variables have 0 objective coefficient
The constraint matrix is given in standard compressed sparse column (without gaps).
-
start[i]stores the starting index of the ith column -
index[k]stores the row index of the kth nonzero element -
value[k]stores the coefficient of the kth nonzero element